@@ -19,7 +19,7 @@ from send2trash import send2trash
 import aqt
 from anki._legacy import DeprecatedNamesMixinForModule
 from anki.collection import Collection, HelpPage
-from anki.lang import TR, tr_legacyglobal  # pylint: disable=unused-import
+from anki.lang import TR, tr_legacyglobal  # noqa: F401
 from anki.utils import (
     call,
     invalid_filename,
@@ -31,7 +31,7 @@ from anki.utils import (
 from aqt.qt import *
 from aqt.qt import (
     PYQT_VERSION_STR,
-    QT_VERSION_STR,
+    QT_VERSION_STR,  # noqa: F401
     QAction,
     QApplication,
     QCheckBox,
@@ -87,24 +87,15 @@ if TYPE_CHECKING:
 
 
 def aqt_data_path() -> Path:
-    # packaged?
-    if getattr(sys, "frozen", False):
-        prefix = Path(sys.prefix)
-        path = prefix / "lib/_aqt/data"
-        if path.exists():
-            return path
-        else:
-            return prefix / "../Resources/_aqt/data"
-    else:
-        import _aqt.colors
+    import _aqt.colors
 
-        data_folder = Path(inspect.getfile(_aqt.colors)).with_name("data")
-        if data_folder.exists():
-            return data_folder.absolute()
-        else:
-            # should only happen when running unit tests
-            print("warning, data folder not found")
-            return Path(".")
+    data_folder = Path(inspect.getfile(_aqt.colors)).with_name("data")
+    if data_folder.exists():
+        return data_folder.absolute()
+    else:
+        # should only happen when running unit tests
+        print("warning, data folder not found")
+        return Path(".")
 
 
 def aqt_data_folder() -> str:
@@ -217,6 +208,7 @@ def ask_user_dialog(
     ) = None,
     default_button: int = 1,
     parent: QWidget | None = None,
+    title: str = "Anki",
     **kwargs: Any,
 ) -> MessageBox:
     "Shows a question to the user, passes the index of the button clicked to the callback."
@@ -229,6 +221,7 @@ def ask_user_dialog(
         buttons=buttons,
         default_button=default_button,
         parent=parent,
+        title=title,
         **kwargs,
     )
 
@@ -301,7 +294,7 @@ def showInfo(
         icon = QMessageBox.Icon.Critical
     else:
         icon = QMessageBox.Icon.Information
-    mb = QMessageBox(parent_widget)  #
+    mb = QMessageBox(parent_widget)
     if textFormat == "plain":
         mb.setTextFormat(Qt.TextFormat.PlainText)
     elif textFormat == "rich":
@@ -558,6 +551,7 @@ def getText(
     d = GetTextDialog(
         parent, prompt, help=help, edit=edit, default=default, title=title, **kwargs
     )
+    add_close_shortcut(d)
     d.setWindowModality(Qt.WindowModality.WindowModal)
     if geomKey:
         restoreGeom(d, geomKey)
@@ -927,7 +921,7 @@ def openFolder(path: str) -> None:
         subprocess.run(["explorer", f"file://{path}"], check=False)
     else:
         with no_bundled_libs():
-            QDesktopServices.openUrl(QUrl(f"file://{path}"))
+            QDesktopServices.openUrl(QUrl.fromLocalFile(path))
 
 
 def show_in_folder(path: str) -> None:
@@ -942,14 +936,39 @@ def show_in_folder(path: str) -> None:
         """
         call(osascript_to_args(script))
     else:
-        # Just open the file in any other platform
-        with no_bundled_libs():
-            QDesktopServices.openUrl(QUrl(f"file://{path}"))
+        # For linux, there are multiple file managers. Let's test if one of the
+        # most common file managers is found and use it in case it is installed.
+        # If none of this list are installed, use a fallback. The fallback
+        # might open the image in a web browser, image viewer or others,
+        # depending on the users defaults.
+        file_managers = [
+            "nautilus",  # GNOME
+            "dolphin",  # KDE
+            "pcmanfm",  # LXDE
+            "thunar",  # XFCE
+            "nemo",  # Cinnamon
+            "caja",  # MATE
+        ]
+
+        available_file_manager = None
+
+        # Test if a file manager is installed and use it, fallback otherwise
+        for file_manager in file_managers:
+            if shutil.which(file_manager):
+                available_file_manager = file_manager
+                break
+
+        if available_file_manager:
+            subprocess.run([available_file_manager, path], check=False)
+        else:
+            # Just open the file in any other platform
+            with no_bundled_libs():
+                QDesktopServices.openUrl(QUrl.fromLocalFile(path))
 
 
 def _show_in_folder_win32(path: str) -> None:
-    import win32con  # pylint: disable=import-error
-    import win32gui  # pylint: disable=import-error
+    import win32con
+    import win32gui
 
     from aqt import mw
 
@@ -986,14 +1005,6 @@ def maybeHideClose(bbox: QDialogButtonBox) -> None:
             bbox.removeButton(b)
 
 
-def addCloseShortcut(widg: QDialog) -> None:
-    if not is_mac:
-        return
-    shortcut = QShortcut(QKeySequence("Ctrl+W"), widg)
-    qconnect(shortcut.activated, widg.reject)
-    setattr(widg, "_closeShortcut", shortcut)
-
-
 def add_close_shortcut(widg: QWidget) -> None:
     if not is_mac:
         return
@@ -1193,7 +1204,7 @@ def disallow_full_screen() -> bool:
     )
 
 
-def add_ellipsis_to_action_label(*actions: QAction) -> None:
+def add_ellipsis_to_action_label(*actions: QAction | QPushButton) -> None:
     """Pass actions to add '...' to their labels, indicating that more input is
     required before they can be performed.
 
@@ -1212,12 +1223,11 @@ def supportText() -> str:
     platname = platform.platform()
 
     return """\
-Anki {} {} {}
+Anki {} {}
 Python {} Qt {} PyQt {}
 Platform: {}
 """.format(
         version_with_build(),
-        "(src)" if not getattr(sys, "frozen", False) else "",
         "(ao)" if mw.addonManager.dirty else "",
         platform.python_version(),
         qVersion(),
@@ -1253,12 +1263,12 @@ def opengl_vendor() -> str | None:
             # Can't use versionFunctions there
             return None
 
-        vp = QOpenGLVersionProfile()  # type: ignore  # pylint: disable=undefined-variable
+        vp = QOpenGLVersionProfile()  # type: ignore
         vp.setVersion(2, 0)
 
         try:
             vf = ctx.versionFunctions(vp)  # type: ignore
-        except ImportError as e:
+        except ImportError:
             return None
 
         if vf is None:
